@@ -1,5 +1,3 @@
-#!/usr/bin/env python
-
 import logging
 import argparse
 import time, signal
@@ -229,5 +227,3 @@ class SockJSProxy(object):
         except KeyboardInterrupt:
             term()
 
-if __name__ == '__main__':
-    SockJSProxy().main()
